@@ -8,7 +8,7 @@ package Future::AsyncAwait;
 use strict;
 use warnings;
 
-our $VERSION = '0.31';
+our $VERSION = '0.33';
 
 use Carp;
 
@@ -295,6 +295,25 @@ C<return> from inside C<try>.
       }
    }
 
+=head2 Syntax::Keyword::Dynamically
+
+As of L<Future::AsyncAwait> version 0.32, cross-module integration tests
+assert that the C<dynamically> correctly works across an C<await> boundary.
+
+   use Future::AsyncAwait;
+   use Syntax::Keyword::Dynamically;
+
+   our $var;
+
+   async sub trial
+   {
+      dynamically $var = "value";
+
+      await func();
+
+      say "Var is still $var";
+   }
+
 =cut
 
 sub import
